* [PATCH] tags: skip ./ in filenames
@ 2008-09-15 16:02 Alexey Dobriyan
0 siblings, 0 replies; only message in thread
From: Alexey Dobriyan @ 2008-09-15 16:02 UTC (permalink / raw)
To: sam, akpm; +Cc: linux-kernel
This drives size of tags file from 68.9 MB down to 67.7 MB.
Signed-off-by: Alexey Dobriyan <adobriyan@gmail.com>
---
Makefile | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
--- a/Makefile
+++ b/Makefile
@@ -1450,7 +1450,7 @@ define find-sources
-name $1 -print; \
find $(__srctree) $(RCS_FIND_IGNORE) \
\( -name include -o -name arch -o -name '.tmp_*' \) -prune -o \
- -name $1 -print; \
+ -name $1 -print | sed -e 's#^./##'; \
)
endef
^ permalink raw reply [flat|nested] only message in thread
only message in thread, other threads:[~2008-09-15 16:00 UTC | newest]
Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2008-09-15 16:02 [PATCH] tags: skip ./ in filenames Alexey Dobriyan
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®